package com.ruoyi.mall.service;

import java.util.List;
import com.ruoyi.mall.domain.MallGoodsSpecValue;

/**
 * 商品规格值Service接口
 * 
 * @author chang
 * @date 2021-11-25
 */
public interface IMallGoodsSpecValueService 
{
    /**
     * 查询商品规格值
     * 
     * @param id 商品规格值主键
     * @return 商品规格值
     */
    public MallGoodsSpecValue selectMallGoodsSpecValueById(Long id);

    /**
     * 查询商品规格值列表
     * 
     * @param mallGoodsSpecValue 商品规格值
     * @return 商品规格值集合
     */
    public List<MallGoodsSpecValue> selectMallGoodsSpecValueList(MallGoodsSpecValue mallGoodsSpecValue);

    /**
     * 新增商品规格值
     * 
     * @param mallGoodsSpecValue 商品规格值
     * @return 结果
     */
    public int insertMallGoodsSpecValue(MallGoodsSpecValue mallGoodsSpecValue);

    /**
     * 修改商品规格值
     * 
     * @param mallGoodsSpecValue 商品规格值
     * @return 结果
     */
    public int updateMallGoodsSpecValue(MallGoodsSpecValue mallGoodsSpecValue);

    /**
     * 批量删除商品规格值
     * 
     * @param ids 需要删除的商品规格值主键集合
     * @return 结果
     */
    public int deleteMallGoodsSpecValueByIds(Long[] ids);

    /**
     * 删除商品规格值信息
     * 
     * @param id 商品规格值主键
     * @return 结果
     */
    public int deleteMallGoodsSpecValueById(Long id);
}
