package com.ruoyi.mall.controller;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.mall.domain.MallGoodsSpecValue;
import com.ruoyi.mall.service.IMallGoodsSpecValueService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 商品规格值Controller
 * 
 * @author chang
 * @date 2021-11-25
 */
@RestController
@RequestMapping("/mall/mallGoodsSpecValue")
public class MallGoodsSpecValueController extends BaseController
{
    @Autowired
    private IMallGoodsSpecValueService mallGoodsSpecValueService;

    /**
     * 查询商品规格值列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpecValue:list')")
    @GetMapping("/list")
    public TableDataInfo list(MallGoodsSpecValue mallGoodsSpecValue)
    {
        startPage();
        List<MallGoodsSpecValue> list = mallGoodsSpecValueService.selectMallGoodsSpecValueList(mallGoodsSpecValue);
        return getDataTable(list);
    }

    /**
     * 导出商品规格值列表
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpecValue:export')")
    @Log(title = "商品规格值", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(MallGoodsSpecValue mallGoodsSpecValue)
    {
        List<MallGoodsSpecValue> list = mallGoodsSpecValueService.selectMallGoodsSpecValueList(mallGoodsSpecValue);
        ExcelUtil<MallGoodsSpecValue> util = new ExcelUtil<MallGoodsSpecValue>(MallGoodsSpecValue.class);
        return util.exportExcel(list, "商品规格值数据");
    }

    /**
     * 获取商品规格值详细信息
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpecValue:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(mallGoodsSpecValueService.selectMallGoodsSpecValueById(id));
    }

    /**
     * 新增商品规格值
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpecValue:add')")
    @Log(title = "商品规格值", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MallGoodsSpecValue mallGoodsSpecValue)
    {
        return toAjax(mallGoodsSpecValueService.insertMallGoodsSpecValue(mallGoodsSpecValue));
    }

    /**
     * 修改商品规格值
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpecValue:edit')")
    @Log(title = "商品规格值", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MallGoodsSpecValue mallGoodsSpecValue)
    {
        return toAjax(mallGoodsSpecValueService.updateMallGoodsSpecValue(mallGoodsSpecValue));
    }

    /**
     * 删除商品规格值
     */
    @PreAuthorize("@ss.hasPermi('mall:mallGoodsSpecValue:remove')")
    @Log(title = "商品规格值", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mallGoodsSpecValueService.deleteMallGoodsSpecValueByIds(ids));
    }
}
